import datetime


def months_between_dates(start_date, end_date):
    """
    Given two instances of ``datetime.date``, generate a list of dates on
    the 1st of every month between the two dates (inclusive).

    e.g. "5 Jan 2020" to "17 May 2020" would generate:

        1 Jan 2020, 1 Feb 2020, 1 Mar 2020, 1 Apr 2020, 1 May 2020

    """
    if start_date > end_date:
        raise ValueError(f"Start date {start_date} is not before end date {end_date}")

    year = start_date.year
    month = start_date.month

    while (year, month) <= (end_date.year, end_date.month):
        yield datetime.date(year, month, 1)

        if month == 12:
            month = 1
            year += 1
        else:
            month += 1



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['admincharts', 'admincharts.migrations']

package_data = \
{'': ['*'],
 'admincharts': ['static/admincharts/*', 'templates/admin/admincharts/*']}

setup_kwargs = {
    'name': 'django-admincharts',
    'version': '0.1.0',
    'description': 'Chart.js integration for Django admin models',
    'long_description': None,
    'author': 'Dave Gaeddert',
    'author_email': 'dave.gaeddert@dropseed.io',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from django.contrib.admin import ModelAdmin


class AdminChartMixin:
    change_list_template = "admin/admincharts/generic_change_list.html"

    list_chart_type = "bar"
    list_chart_data = {}
    list_chart_options = {"aspectRatio": 6}
    list_chart_config = None  # Override the combined settings

    class Media:
        css = {"all": ("admincharts/admincharts.css",)}
        js = (
            "admincharts/chart.min.js",
            "admincharts/admincharts.js",
        )

    def get_list_chart_queryset(self, result_list):
        """Returns the current changelist results by default"""
        return result_list

    def get_list_chart_type(self, queryset):
        return self.list_chart_type

    def get_list_chart_data(self, queryset):
        return self.list_chart_data

    def get_list_chart_options(self, queryset):
        return self.list_chart_options

    def get_list_chart_config(self, queryset):
        if self.list_chart_config:
            return self.list_chart_config

        return {
            "type": self.get_list_chart_type(queryset),
            "data": self.get_list_chart_data(queryset),
            "options": self.get_list_chart_options(queryset),
        }

    def changelist_view(self, request, extra_context=None):
        response = super().changelist_view(request, extra_context=extra_context)

        if "cl" in response.context_data:
            changelist = response.context_data["cl"]
            chart_queryset = self.get_list_chart_queryset(changelist.result_list)
            response.context_data["adminchart_queryset"] = chart_queryset
            response.context_data[
                "adminchart_chartjs_config"
            ] = self.get_list_chart_config(chart_queryset)
        else:
            response.context_data["adminchart_queryset"] = None
            response.context_data["adminchart_chartjs_config"] = None

        return response
